#
# spec file for package qmmp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   1
%bcond_with faad
%bcond_with mad
%bcond_with restricted
Name:           qmmp
Version:        1.1.7
Release:        1.1
Summary:        Qt-based Multimedia Player
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://qmmp.ylsoftware.com/
Source:         http://qmmp.ylsoftware.com/files/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM qmmp-fix_cdda_version.patch pascal.bleser@opensuse.org -- Fix header detection for cdparanoia cdda.h.
Patch0:         %{name}-fix_cdda_version.patch
# PATCH-FEATURE-OPENSUSE qmmp-default_pulse.patch reddwarf@opensuse.org -- Use PulseAudio instead of ALSA by default.
Patch1:         %{name}-default-pulse.patch
# PATCH-FIX-OPENSUSE qmmp-taglib-1.9.patch -- Extend TagLib support to 1.9.
Patch2:         %{name}-taglib-1.9.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmpcdec-devel
BuildRequires:  libqt5-qttools-devel >= 5.4
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.4
BuildRequires:  pkgconfig(Qt5DBus) >= 5.4
BuildRequires:  pkgconfig(Qt5Multimedia) >= 5.4
BuildRequires:  pkgconfig(Qt5Network) >= 5.4
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.4
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.4
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.4
BuildRequires:  pkgconfig(Qt5Xml) >= 5.4
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(enca) >= 1.9
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libmms)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libsidplayfp)
BuildRequires:  pkgconfig(opus) >= 1.0.2
BuildRequires:  pkgconfig(opusfile) >= 0.2
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(taglib) >= 1.9
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
Requires:       %{name}(%{sover})(Input)
Requires:       %{name}(%{sover})(Output)
Requires:       %{name}(%{sover})(Ui)
%if %{with faad}
BuildRequires:  libfaad-devel
%endif
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif

%description
This program is an audio-player, written with help of Qt library.

%package -n lib%{name}%{sover}
Summary:        Qmmp library
Group:          System/Libraries
Recommends:     lib%{name}-plugins

%description -n lib%{name}%{sover}
This program is an audio-player, written with help of Qt library.

This package provides the Qmmp library.

%package -n lib%{name}-plugins
Summary:        Plugins for libqmmp
# Suggests instead of Recommends since MPlayer is a too big dependency.
Group:          System/Libraries
Suggests:       lib%{name}-plugin-mplayer
Provides:       %{name}(%{sover})(Input)
Provides:       %{name}(%{sover})(Output)
Provides:       %{name}(%{sover})(Ui)
# libqmmp0-plugins & qmmp-plugin-pack-simple-ui were last used in openSUSE 13.2 (in PMBS).
Provides:       %{name}-plugin-pack-simple-ui = %{version}
Obsoletes:      %{name}-plugin-pack-simple-ui < %{version}
Obsoletes:      lib%{name}0-plugins

%description -n lib%{name}-plugins
This program is an audio-player, written with help of Qt library.

This package provides plugins for libqmmp.

%if %{with restricted}
%package -n lib%{name}-plugin-mplayer
Summary:        MPlayer plugin for libqmmp
Group:          System/Libraries
Requires:       MPlayer

%description -n lib%{name}-plugin-mplayer
This program is an audio-player, written with help of Qt library.

This package provides MPlayer plugin for libqmmp.
%endif

%package -n lib%{name}-devel
Summary:        Development files for libqmmp
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description -n lib%{name}-devel
This program is an audio-player, written with help of Qt library.

Development files for libqmmp.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1

%build
%cmake \
  -DCMAKE_MODULE_LINKER_FLAGS=""      \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
  -DLIB_DIR=%{_lib}                   \
%if %{without restricted}
  -DUSE_MPLAYER=OFF                   \
%endif
  -DUSE_HAL=OFF                       \
  -DUSE_OSS=OFF                       \
  -DUSE_OSS4=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n lib%{name}%{sover} -p /sbin/ldconfig

%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%post -n lib%{name}-plugins
%desktop_database_post

%postun -n lib%{name}-plugins
%desktop_database_postun

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*

%files -n lib%{name}%{sover}
%defattr(-,root,root)
%{_libdir}/lib%{name}*.so.%{sover}*

%files -n lib%{name}-plugins
%defattr(-,root,root)
%{_libdir}/%{name}/
%exclude %{_libdir}/%{name}/Engines/libmplayer.so

%if %{with restricted}
%files -n lib%{name}-plugin-mplayer
%defattr(-,root,root)
%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/Engines/
%{_libdir}/%{name}/Engines/libmplayer.so
%endif

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_includedir}/%{name}ui/
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}ui.pc

%changelog
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.1.7:
  * Improve stream format determination in the ffmpeg plugin.
  * Fix GCC 6.x support.
  * Fix a possible segmentation fault.
  * Fix a crash when using KDE file dialogue.
  * Fix saving state of the visual plugins.
  * Update Brazilian Portuguese translation.
* Thu Jan 12 2017 sor.alexei@meowr.ru
- Update to version 1.1.6:
  * Use the HTTP header 'icy-name' as a fallback title.
  * Enable AAC by default in the ffmpeg plugin.
  * Fix the ADTS parser in the AAC plugin.
  * Fix a possible segmentation fault.
  * Fix Ogg Opus streams support.
  * Update the Chinese Simplified translation.
* Wed Nov  9 2016 sor.alexei@meowr.ru
- Update to version 1.1.5:
  * Add FFmpeg 3.2 support.
  * Fix file downloading issue in the http plugin.
  * Fix directory selection in the qsui plugin.
  * Fix a possible segmentation fault.
  * Fix command line option '--pl-repeat-toggle'.
  * Fix some cppcheck warnings.
  * Change a file dialogue form.
* Wed Oct  5 2016 sor.alexei@meowr.ru
- Update to version 1.1.4:
  * Fix support of skins UTF-16 with encoded pledit.txt.
  * Fix 'index out of range' warning.
  * Fix typo in the qsui plugin.
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * Add a xesam:contentCreated field in the mpris plugin.
  * Improve ape/tta detection.
  * Fix random stop bug.
  * Fix duration calculation in the mpeg plugin.
  * Fix scrobbling of tracks with '&' symbol.
  * Fix ADTS parser in the aac plugin.
  * Fix librcc database path in the portable mode.
  * Update Brazilian Portuguese and German translations.
* Thu Aug  4 2016 olaf@aepfle.de
- Use buildconditional for faad and mad support
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 1.1.2:
  * Fix path to equaliser presets file in the qsui plugin.
  * Fix buffer overflow.
* Mon Jul  4 2016 sor.alexei@meowr.ru
- Update to version 1.1.1:
  * Add FFmpeg 3.1 support.
  * Fix Qt 5.7 support.
  * Fix Russian translation.
  * Update Ukrainian, Portuguese translation.
- Rebase qmmp-taglib-1.9.patch.
* Wed Jun 29 2016 sor.alexei@meowr.ru
- Add qmmp-taglib-1.9.patch: extend TagLib support to 1.9.
* Tue Jun 21 2016 sor.alexei@meowr.ru
- Update to version 1.1.0:
  * Use floating point pcm format for all lossy decoders.
  * Use floating point pcm format for all audio effects.
  * Add new internal audio converter.
  * Add dithering setting.
  * Add feature to change output bit depth.
  * Add feature to change volume adjustment step.
  * Add soxr-based resampler plugin.
  * Remove libsamplerate-based resampler.
  * Add Qt Multimedia output plugin.
  * Add feature to refresh playlist.
  * Add two-panel file dialog.
  * Add feature to scrobble http streams.
  * Add multi-thread support in the audio converter plugin.
  * Add support for m4a files in the ReplayGain scanner.
  * Add WASAPI output plugin.
  * Add https support in the http plugin.
  * Add wildmidi 0.4.0 support.
  * Add support for XMIDI and MUS (id Software) formats.
  * Improve skinned interface:
  - show track details when double-clicking on song title in the
    main window;
  - improve time indicator in the shaded mode;
  - add feature to disable anti-aliasing;
  - add feature to seek by mouse wheel;
  - add column alignment option.
  * Improve simple user interface (qsui):
  - add column alignment option;
  - add feature to add/remove sliders;
  - add feature to create multiple panels;
  - add tooltips for the sliders;
  - improve volume slider;
  - fix problem with minimum width.
  * Improve wavpack plugin:
  - add some optimisations;
  - fix a memory leak.
  * Improve ffmpeg plugin:
  - add support for m4a embedded album art;
  - add replaygain support
  * Improve ladspa plugin.
  * Improve command line parser.
  * Improve details dialog.
  * Improve "jump to track" dialog.
  * Change default settings in the mpeg plugin.
  * Fix metadata encoding issue in the http plugin.
  * Fix compiz support.
  * Fix disc number parsing.
  * Update Bulgarian translation, Chinese Traditional,
    Chinese Simplified, French, German, Greek, Hebrew, Japanese,
    Portuguese, Russian, Ukrainian translations.
- Rebase qmmp-default-pulse.patch.
* Tue May 31 2016 sor.alexei@meowr.ru
- Update to version 1.0.10:
  * Improve sid plugin:
    + add c64 file extension;
    + fix default HVSC path.
  * Update Japanese translation.
* Tue May  3 2016 sor.alexei@meowr.ru
- Update to version 1.0.9 (changes since 1.0.7):
  * Fix session check in the scrobbler plugin.
  * Fix working with both libre.fm and last.fm.
  * Fix cell height in the stream browser.
  * Remove borders from statusbar in the qsui plugin.
  * Fix taglib-1.9 support.
* Sun Apr  3 2016 sor.alexei@meowr.ru
- Update to 1.0.7:
  * Add ffmpeg 3.0 support.
  * Add support for theme change event in the qsui plugin.
  * Fix sending multiple play commands when opening several files
    for playback.
  * Fix memory leaks.
  * Fix Qt 5.6 support.
* Sat Jan 30 2016 rpm@fthiessen.de
- Fixed build by rebasing qmmp-default-pulse.patch
  to work with 1.0.6
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to 1.0.6:
  * Add a feature to change default output plugin.
  * Add a feature to skip unsupported files in the rgscan plugin.
  * Fix gme plugin building.
  * Fix GCC warnings.
  * Fix Russian translation.
  * Update Portuguese, Chinese Simplified translations
* Sat Jan  2 2016 sor.alexei@meowr.ru
- Update to 1.0.5:
  * Add GNOME Shell support.
  * Fix url dialog size.
  * Fix memory leak in the qsui plugin.
  * Fix LADSPA plugin.
  * Fix CPU usage in the vorbis plugins.
  * Fix UTF-8 support in the scrobbler plugin.
  * Fix Greek translation.
  * Update French translation.
* Mon Dec 21 2015 sor.alexei@meowr.ru
- Update to 1.0.4:
  * Fix skinned ui build.
* Thu Dec 17 2015 sor.alexei@meowr.ru
- Update to 1.0.3:
  * Add error handling in the MPlayer plugin.
  * Fix problem with some covers embedded in the mp3 files.
  * Fix some skins support.
  * Fix issue with equaliser not saving low levels in the qsui
    plugin.
  * Fix gcc warnings.
  * Fix build without Qt X11 Extras.
  * Fix Cinnamon and MATE support.
  * Update Chinese Simplified translation.
* Sun Nov 15 2015 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Fix problem with tray icon menu (see qtbug#48869).
  * Fix geometry saving in the skinned UI.
  * Fix segmentation fault in the ReplayGain scanner.
  * Fix hide on close feature.
  * Fix some skins parsing.
  * Fix Dutch translation.
* Wed Nov  4 2015 sor.alexei@meowr.ru
- Update to 1.0.1 (changes since 0.9.3):
  * Switch to Qt5.
  * Add Xfce icon theme support.
  * Add test for supported OpenGL implementation while using cmake.
  * Remove ffmpeg_legacy plugin.
  * Remove legacy udisks plugin.
  * Remove support of taglib versions less than 1.8.
- Switch to Qt5.
* Thu Oct 22 2015 sor.alexei@meowr.ru
- Update to 0.9.3:
  * Improve command line parser.
  * Fix crash in the mplayer engine.
  * Fix time indicator in the qsui plugin.
  * Fix truncated output of the '--pl-dump' command.
  * Fix track indexes calculation.
* Fri Oct  2 2015 sor.alexei@meowr.ru
- Update to 0.9.2:
  * Optimise equaliser.
  * Optimise FLAC and WavPack plugins.
  * Improve skinned UI in the shaded mode:
  - improved time indicator;
  - fixed playlist colours.
  * Fix clicks while playing some MP3 files.
  * Fix memory leak in the WavPack plugin.
  * Fix Qt 4.6 support.
  * Fix ffmpeg 0.5 support.
  * Fix effects and decoders sorting.
  * Fix possible race condition.
  * Update Greek translation.
- Rename libqmmp1-plugins to libqmmp-plugins: can't be
  multiversioned.
- Only install libqmmp-plugin-mplayer in PMBS.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.9.1:
  * Fix 16-bit converter.
  * Improve Russian translation.
- Rename & rebase qmmp-0.6.1-default_pulse.patch to
  qmmp-default-pulse.patch.
- Build with ffmpeg support outside PMBS as well.
- Do not force UNIX permissions in %%files globally.
- Obsolete qmmp-plugin-pack-simple-ui as it's merged with
  libqmmp0-plugins.
* Sat Sep  5 2015 quarckster@gmail.com
- Update to 0.9.0:
  * added "Save List" action to the tab menu;
  * added *.med files support;
  * added 9 channels support to equalizer;
  * added album artist tag support;
  * added asynchronous sorting;
  * added audio-channel sequence converter;
  * added default hotkey for the "Rename List" action;
  * added feature to change user agent;
  * added feature to change window title;
  * added feature to disable fadeout in the gme plugin;
  * added feature to disable plugins without qmmp.pri modification (qmake only)
  * added feature to exclude cue data files;
  * added feature to hide song length;
  * added feature to hide track length;
  * added feature to move files;
  * added feature to remember playlist scroll position;
  * added feature to reset fonts;
  * added feature to reset shortcuts;
  * added feature to restore default shortcuts;
  * added multiple column support;
  * added s3m, stm and xm extensions to desktop files;
  * added Simple User Interface (QSUI) with the following changes:
  * added sorting by album artist;
  * added sorting by file modification date;
  * changed default playlist separator;
  * changed default skin to Glare;
  * fixed cmake support;
  * fixed config directory path;
  * fixed crash when quitting while playlist is being populated;
  * fixed details dialog form;
  * fixed documentation;
  * fixed home page;
  * fixed main window activation;
  * fixed minimizing throw taskbar under windows;
  * fixed opus plugin;
  * fixed some skins parsing;
  * fixed some skins support;
  * fixed support of keyboards with single play/pause button;
  * fixed text scroller colors;
  * fixed typos;
  * improved ape tags support in the mpeg plugin;
  * improved cmake build scripts;
  * improved fileops plugin:
  * improved global hotkey settings;
  * improved playlist changes notification;
  * improved status bar;
  * improved title formatter;
  * increased details dialog size;
  * optimized playlist container;
  * optimized sample rate converter;
  * reduced cpu usage;
  * reworked settings dialog;
  * updated Czech translation;
  * updated French translation;
  * updated German translation;
  * updated Greek translation;
  * updated Hebrew translation;
  * updated Japanese translation;
  * updated Japanese translation;
  * updated Polish translation;
  * updated Portuguese translation;
  * updated Russian translation;
  * updated Ukrainian translation;
  * using DirectSound output as default under Windows.
* Tue Jun  9 2015 quarckster@gmail.com
- Update to 0.8.5
  * added icons for some actions;
  * fixed multiple connections to same signal when switching playlists;
  * fixed api documentation;
  * fixed playlist selector drawing bug;
  * fixed Portuguese translation;
  * fixed Hebrew translation;
  * updated Turkish translation;
  * added user data directory support;
  * increased player thread priority under windows;
  * fixed playlist resizing on RTL locales;
  * fixed vorbis comment support;
  * fixed build using qmake;
  * fixed cover disappearing bug;
  * fixed windows executable file description;
  * fixed settings form;
  * fixed problem with path separators under windows;
  * fixed libre.fm support;
  * fixed some skin parsing;
  * fixed support of some skins;
  * fixed modplug plugin settings.
* Tue Jan  6 2015 quarckster@gmail.com
- Update to 0.8.3
  * reduced time of the 'Randomize List' and "Remove Duplicates" operations;
  * fixed ffmpeg 2.5 support;
  * fixed 24/32 bit modes in the equalizer;
  * fixed skin parsing;
  * fixed autoplay when playlist was opened from command line;
  * updated Portuguese translation;
  * updated Czech translation.
* Tue Oct 21 2014 quarckster@gmail.com
- Update to 0.8.2
  * added transifex integration;
  * added webm support;
  * improved image scaling quality;
  * fixed xspf parsing;
  * fixed cover loading sequence;
  * fixed main window activation under windows;
  * fixed analyzer color settings;
  * fixed typos;
  * fixed possible segmentation fault in the opus;
  * fixed separator of the file filters;
  * reduced tag reading delay (requires TagLib 1.8 or higher);
  * updated Russian translation;
  * updated Ukrainian translation;
  * updated Japanese translation.
  * added rusxmms patch autodetection to the mpg123 plugin;
  * fixed selection behaviour when using keyboard in the qsui plugin;
  * fixed main window activation in the qsui plugin.
* Fri Jul 11 2014 reddwarf@opensuse.org
- Update to 0.8.0
  * added sid plugin
  * added ReplayGain scanner
  * added gnome hotkey plugin
  * added DirectSound plugin
  * added track grouping view
  * added sorting by group
  * added quick search to the playlist browser
  * added multiple tracks support to the details dialog
  * added context menu to the plugin settings page
  * added lazy plugin loading
  * added feature to disable transport plugins
  * added data waiting condition for transport plugins
  * added floating point output for lossy decoders
  * added peak overflow support for lossy decoders
  * added support for id3v2-based ReplayGain tags
  * added clipping prevention using ReplayGain information
  * added delayed initialization in the wildmidi plugin
  * added volume control hotkeys
  * added 'mute' global hotkey
  * added '--toggle-mute' command line option
  * added '--show-mw' command line option
  * added ogg opus preset to the converter plugin
  * added scrobbler 2.0 api for libre.fm
  * added context menu in the window of the analyzer plugin
  * added window flags access from visual plugin api
  * added atomic playlist saving operation
  * added created playlist auto-selection
  * added feature to not clear previous playlist when opening new one
  * added mplayer command line options setting
  * added Serbian translation (Mladen Pejaković)
  * blocked one hotkey assignment for several commands in the hotkey plugin
  * limited cover cache size
  * improved 'jump to track' dialog
  * improved projectm plugin:
  - added context menu
  - added multi-channel mode
  - added list of presets
  - added win32 support
  * improved win32 support
  - enabled support for the enca library
  - added feature to add files from multiple instances
  - added file associations support (based on SMPlayer implementation)
  - added uninstall support
  * fixed noise on buffer underrun
  * fixed title format in the shaded mode
  * fixed alt-f4 behavior
  * fixed possible race condition
  * fixed possible segmentation fault in the mad plugin
  * fixed 'eject' button function
  * fixed raise of the main window when starting another instance
  * fixed default skin
  * updated Russian translation
  * updated Hebrew translation (Genghis Khan)
  * updated Ukrainian translation (Gennadi Motsyo)
  * updated Serbian translation (Mladen Pejaković)
  * updated Polish translation (Grzegorz Gibas)
  * updated Lithuanian translation (Algirdas Butkus)
- Add pkgconfig(libsidplayfp) build dependency
* Fri Jun  6 2014 reddwarf@opensuse.org
- Update to 0.7.7
  * fixed typos
  * fixed Polish locale support
  * removed 'OnlyShowIn' key from qmmp.desktop
  * removed useless files
* Wed Apr 16 2014 reddwarf@opensuse.org
- Update to 0.7.6
  * added libav 10 and ffmpeg 2.2 support
  * fixed url parsing
  * fixed freezing on playback resume
  * fixed random freezing in the mplayer plugin
  * fixed reset selection of tracks when calling context menu
  * fixed multimedia keys support under win32
* Thu Feb 13 2014 reddwarf@opensuse.org
- Update to 0.7.5
  * fixed case sensitivity while checking file extensions (tnanks to Ryota Shimamoto)
  * fixed special global keys support under the win32 platform
  * fixed latest cmake support
  * fixed initial position of the equalizer volume slider
  * fixed clang warnings
- Update to 0.7.4
  * added Galician translation (Óscar Pereira)
  * added ffmpeg 2.1 support
  * added m3u8 playlist extension
  * improved ReplayGain support:
  - fixed 24/32 bit mode
  - added clipping to prevent overflow
  * improved cdaudio plugin:
  - added Windows support
  - added track cache
  - fixed proxy support
  * fixed localization of the wildmidi plugin
  * fixed case sensitivity while checking file extensions
  * fixed gcc 4.8 warnings
  * fixed memory leak
  * fixed several Windows-only bugs:
  - fixed parsing of the m3u files with backslashes
  - fixed problem with absolute paths
  - fixed adding files from command line under Windows
  - fixed Meta/Win modifier in the global hotkey plugin
  * fixed Japanese translation (RyōTa SimaMoto)
* Thu Oct  3 2013 reddwarf@opensuse.org
- Update to 0.7.3
  * added window size and position saving to the projectm plugin
  * disabled unsupported settings in the statusicon plugin under Windows
  * fixed warnings about invalid parent thread
  * fixed race condition
  * fixed ReplayGain support in the flac plugin
  * fixed parsing of the track/disc number with separator
  * fixed tooltip in the status icon plugin under Windows
  * fixed 'show tooltip' option in the status icon plugin
  * removed unused variables
* Wed Aug 28 2013 reddwarf@opensuse.org
- Update to 0.7.2
  * fixed queue update bug
  * fixed track length formatting
  * fixed api documentation
  * fixed gcc warnings
  * fixed memory leaks
  * fixed wildmidi config path
  * fixed playlist autosave feature
  * fixed possible segmentation fault
  * fixed title format update bug
  * removed unimplemented function
* Fri May 31 2013 reddwarf@opensuse.org
- Update to 0.7.1
  * improved jack plugin (24/32-bit samples and freebsd support)
  * excluded mime types of disabled plugins in the mpris interface
  * fixed windows support in the gme plugin
  * fixed shortcut editor dialog
  * fixed api documentation
  * fixed parsing of the icy packet size
  * fixed possible freezes
  * fixed Spanish translation (thanks to Gustavo Alvarez)
  * fixed and improved qmake support (Ryota Shimamoto)
  * fixed pkg-config support
  * fixed several ui bugs
  * fixed scrobbler regressions
* Wed May 15 2013 mhrusecky@suse.com
- Only suggesting instead of recomending mplayer plugin as mplayer is not in
  factory yet
* Mon Apr 15 2013 pascal.bleser@opensuse.org
- update to 0.7.0:
  * added udisks2 plugin
  * added opus plugin
  * added track change plugin
  * added tracks copy/paste plugin
  * added x-content/audio-cdda content type
  * added 24/32-bit equalizer
  * added unity integration
  * added user interface language option
  * added playlists auto-save feature
  * added unified URL dialog
  * added playlists downloading support to the command line parser
  * added volume control support to the waveout plugin
  * added wildmidi configuration file auto-search
  * added sorting by file creation date
  * added automatic 16-bit audio converter
  * added pause handling to the scrobbler plugin
  * enabled UTF-8 by default for cue files and shoutcast metadata
  * enabled more formats by default in the ffmpeg plugin
  * improved analyzer plugin (variable size, fullscreen mode, etc)
  * improved last.fm registration
  * improved configuration dialog
  * removed QtXML dependence from the scrobbler plugin
  * disabled udisks plugin by default
* Thu Mar 28 2013 reddwarf@opensuse.org
- Update to 0.6.8
  * fixed bugs in the mpris plugin
  * fixed segmentation fault when running without output plugins
  * updated Japanese translation (Ryota Shimamo)
* Thu Feb 21 2013 reddwarf@opensuse.org
- Update to 0.6.7
  * added lubuntu integration
  * improved rtl locales support
  * fixed latest paranoia support
  * fixed libav 0.8.x support
  * fixed 'enter' hotkey in the playlist browser
  * fixed 24-bit mode support in the src plugin
  * fixed compiler warnings
* Fri Jan 11 2013 reddwarf@opensuse.org
- Update to 0.6.6
  * added support for http redirect to the url dialog
  * added ffmpeg 1.1 support
  * fixed 24/32-bit mode support in the src plugin
  * fixed seeking when using oss4 as output
  * fixed streaming support in the ffmpeg plugin
  * fixed build without qt3support headers (thanks to Dmitry Smolin)
  * fixed playlist titlebar cursor
  * fixed mpris2 support
  * fixed typos
  * updated Hebrew translation (Genghis Khan)
- Disable OSS/OSS4 output support
* Sun Dec  9 2012 reddwarf@opensuse.org
- Update to 0.6.5
  * added latest psi/psi+ support
  * added Hebrew translation (Genghis Khan)
  * increased default mms/http buffer size
  * fixed shortcut dialogs
  * fixed segmentation fault caused by http transport
  * fixed file type determination by content
  * fixed division line position in the playlist
  * fixed some bugs in the WaveOut plugin
  * updated Japanese translation (Ryota Shimamoto)
  * updated Russian translation
  * updated flac mime-type (Christian Morales Vega)
- Drop qmmp-0.6.4-flac_mimetype.patch. Applied upstream.
* Thu Dec  6 2012 reddwarf@opensuse.org
- Add qmmp-0.6.4-flac_mimetype.patch to use the correct MIME type
  to report support for FLAC files
* Sun Nov  4 2012 reddwarf@opensuse.org
- Update to 0.6.4
  * using UTF-8 encoding for shoutcast metadata by default
  * fixed visualization menu update after changing settings
  * fixed skinned user interface settings
  * fixed analyzer falloff speeds
  * fixed skinned user interface visualization switching
  * fixed playlist titlebar resize bug
  * fixed color selection widget
  * fixed possible crash in the transport plugins
  * fixed Russian translation
  * updated Japanese translation (Ryota Shimamoto)
* Wed Aug 22 2012 reddwarf@opensuse.org
- Update to 0.6.3
  * fixed typo in the about dialog
  * fixed FSF address
  * fixed cmake scripts
  * fixed filters of the directory scanner
  * fixed crash in the playlist popup message
  * updated Lithuanian translation (Algirdas Butkus)
- Removed qmmp-0.5.5-libcdio_mess.patch, fixed upstream
* Sat Aug  4 2012 reddwarf@opensuse.org
- Make qmmp require at least an input, output and ui plugin
* Mon Jul 30 2012 reddwarf@opensuse.org
- Update to 0.6.2
  * fixed crash in the http plugin
  * fixed possible crash in the cue parser
* Mon Jul 23 2012 reddwarf@opensuse.org
- Update to 0.6.1
  * added icons to the file dialog buttons
  * fixed icecast streams titles
  * fixed build
  * fixed default output under windows
  * fixed api documentation
  * fixed possible segmentation fault in the cue plugin
  * fixed cue parsing
  * fixed automatic charset detection
  * fixed Ukrainian translation (Gennadi Motsyo)
  * fixed Russian translation
* Sat Jun 30 2012 reddwarf@opensuse.org
- Update to 0.6.0
  * added converter plugin
  * added stream browser plugin
  * added file type determination by content (experimental)
  * added '--quit' command line option
  * added text scroller background option
  * added playlists separator option
  * added multiband equalizer api
  * added equalizer presets from Amarok (Thanks to Panagiotis Papadopoulos)
  * added playlits access from command line
  * added dithering to MPEG plugin
  * added priority support to decoder api
  * added user interface api
  * added default destination and file name pattern to fileops plugin
  * added additional directory filters
  * added feature to add files from command line to specific playlist
  * added pkg-config support
  * added vqf support
  * added feature to display shoutcast stream information
  * added 'jump to track' and 'forward/rewind' global hotkeys
  * added 'New Playlist' button
  * added sorting by disc number (Brice Videau)
  * added feature to use clipboard content in the URL dialog (Panagiotis Papadopoulos)
  * added scrobbler cache synchronization after successful submission (Ferdinand Vesely)
  * changed playlist insertion behavior
  * disabled OSS3 plugin by default
  * improved cue plugin
  * moved skinned ui to separate plugin
  * fixed 'hide on close' feature
  * fixed moc warnings during compilation
  * fixed IPC under windows
  * fixed windows-specific bugs
  * fixed problems with some asynchronous calls
  * fixed qmmp_cue.desktop
  * fixed saving playlists on logout
  * updated about dialog
  * updated Russian translation
  * updated Ukrainian translation (Gennadi Motsyo)
  * updated Japanese translation (Ryota Shimamoto)
  * updated Polish translation (Grzegorz Gibas)
  * updated German translation (Panagiotis Papadopoulos)
  * updated Dutch translation (Ronald Uitermark)
* Thu May 31 2012 reddwarf@opensuse.org
- Disable HAL plugin build
- Disable OSS plugin build
- Use PulseAudio by default instead of ALSA
* Sun May 27 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Sat May 26 2012 reddwarf@opensuse.org
- Update to 0.5.5
  * added latest libcdio support
  * fixed Russian translation
  * fixed acc streams support
  * fixed aac bitrate calculation
  * fixed scrobbler failure when using Qt 4.8
  * fixed some cuesheets parsing
  * fixed --pause command line option behavior
  * updated Japanese translation
- Add missing %%desktop_database_post and %%icon_theme_cache_post
  scripts
- Remove obsoleted %%suse_update_desktop_file calls
- Add qmmp-0.5.5-libcdio_mess.patch to fix build with git version
  of libcdio
* Mon Sep  6 2010 reddwarf@opensuse.org
- New package. Version 0.4.2
